@@ -1,6 +1,7 @@
 package Hailo::Tokenizer::Words;
-
+use 5.10.0;
 use Moose;
+use MooseX::StrictConstructor;
 use List::MoreUtils qw<uniq>;
 use namespace::clean -except => 'meta';
 
